referrerpolicy=no-referrer-when-downgrade

Type Alias FullSupportsOfMiner

pub type FullSupportsOfMiner<T> = BoundedSupports<<T as MinerConfig>::AccountId, MaxWinnersFinal<T>, <T as MinerConfig>::MaxBackersPerWinnerFinal>;
The full version of PageSupportsOfMiner.

This should be used on a support instance that is encapsulating the full solution.

Another way to look at it, this is never wrapped in a Vec<_>

Aliased Type

struct FullSupportsOfMiner<T>(pub BoundedVec<(<T as MinerConfig>::AccountId, BoundedSupport<<T as MinerConfig>::AccountId, <T as MinerConfig>::MaxBackersPerWinnerFinal>), MaxWinnersFinal<T>>);

Fields

0: BoundedVec<(<T as MinerConfig>::AccountId, BoundedSupport<<T as MinerConfig>::AccountId, <T as MinerConfig>::MaxBackersPerWinnerFinal>), MaxWinnersFinal<T>>